pub struct StateBucket {
pub shared_state: Value,
pub history: VecDeque<ToolCallRecord>,
/* private fields */
}Expand description
Mutable state shared across tool calls with the same state_key.
Fields
history: VecDeque<ToolCallRecord>Implementations
Sourceimpl StateBucket
impl StateBucket
Sourcepub fn with_capacity(history_cap: usize) -> Self
pub fn with_capacity(history_cap: usize) -> Self
A cap of 0 is promoted to 1.
Sourcepub fn record(&mut self, record: ToolCallRecord)
pub fn record(&mut self, record: ToolCallRecord)
Record a call, evicting the oldest if we exceed the cap.
pub const fn history_cap(&self) -> usize