FsEvalStore

Struct FsEvalStore 

pub struct FsEvalStore { /* private fields */ }
Filesystem-backed eval store using JSON files.

Directory layout:

{dir}/sets/{id}.json
{dir}/results/{eval_set_id}/{timestamp}.json

Implementations

Source

impl FsEvalStore

pub fn new(dir: impl Into<PathBuf>) -> Self

Create a new store rooted at the given directory.

The directory and subdirectories are created on first write.